==> ysmv7_2.9.6.orig.tar.gz: ysmv7_2_9_6/src/YSMLangs/english.h <==
/*	$Id: english.h,v 1.9 2002/12/21 17:29:04 rad2k Exp $	*/

/*
 * YSM Language Specific header file
 *
 *	ENGLISH LANGUAGE
 *
 * by rad2k
 *
 */


/* YSM STARTING MESSAGES */

#define MSG_STARTING_ONE	"..an" WHITE " Experience" NORMAL " you will never forget.."
#define MSG_STARTING_TWO	"[ INITIALIZING YSM ][ " BLUE "UIN" NORMAL " TO USE :"
#define MSG_FOUND_SECPASS	"Found a Secured Password. I love Paranoid users ;)."
#define MSG_FOUND_SECPASS2	"Type again [verification]: "
#define MSG_READ_SLAVES		"YSM Amount of Slaves in db" BRIGHT_BLUE " ["
#define MSG_ASK_KEYMAP1		"Default shortcuts are: "
#define MSG_ASK_KEYMAP2		"Would you like to re-configure your key map? [Y/N]:"
#define MSG_NETWORK_INFO	"[Network Information: TCP local port:"
#define MSG_NETWORK_INFO2	"Ok New srv. Information arrived."
#define MSG_NETWORK_INFO3	"Connecting to the BOS 2nd Server.."
#define MSG_LOGIN_OK		BLUE "Login OK!" NORMAL " << Welcome to the ICQ Network >>"
#define MSG_ASK_DOWNLOAD1	"AVAILABLE Contacts stored in the ICQ servers were found."
#define MSG_ASK_DOWNLOAD2	"Do you wish to download them? [Y/N]: "
#define MSG_DOWNLOADED_SLAVES	"downloaded SLAVES belong to your kingdom."

/* YSM SLAVES INTERACTION MESSAGES */

#define MSG_STATUS_CHANGE1	"[A Slave #"
#define MSG_STATUS_CHANGE2	", called" BLUE
#define MSG_STATUS_CHANGE3	NORMAL "changed his mood to:"

#define MSG_STATUS_HIDE1	"[A Slave #"
#define MSG_STATUS_HIDE2	", called" BLUE
#define MSG_STATUS_HIDE3	NORMAL "hides from you in:"

#define MSG_MESSAGE_SENT1	MAGENTA "YSM Msg Sent to Slave called" WHITE
#define MSG_MESSAGE_SENT2	MAGENTA "YSM Msg Sent to" WHITE

#define MSG_MESSAGE_SENT3	MAGENTA	"Encrypted Msg Sent to Slave called" WHITE
#define MSG_MESSAGE_SENT4	MAGENTA	"Encrypted Msg Sent to" WHITE

#define MSG_INCOMING_MESSAGE	"[Incoming Msg]"
#define MSG_INCOMING_URL	"[Incoming URL]"
#define MSG_INCOMING_AUTHR	"Incoming Authorization Request from"

#define MSG_INCOMING_PAGER	"[Pager Message]"

#define MSG_SLAVES_LIST		"You OWN the Following"
#define MSG_SLAVES_ONLINE	"These are the CURRENTLY ONLINE SLAVES you own:"

#define MSG_SLAVES_BIRTHDAY	WHITE "BIRTHDAY" NORMAL

#define MSG_WARN_ADDED		"Get Paranoid! an ICQ user added you to his/her list!"
#define MSG_WARN_AUTHOK		"Fine! You were authorized to make him/her your Slave by the ICQ"
#define MSG_WARN_AUTHDENY	"WTF! the redneck bastard -DENIED- your Auth request"

/* YSM AFK RELATED MESSAGES */

#define MSG_IDLE_TIME_REACHED	"IDLE Time reached. going afk..\n"
#define MSG_AFK_MODE_ON		"You are " BRIGHT_BLUE "now in AFK" NORMAL " mode (Away From Keyboard).\nIncoming Messages will be logged and an autoreply will be sent\nto anyone who messages you.\nyou can then type 'afk' again to leave AFK mode. enjoy your coffee ;)"

#define MSG_AFK_MODE_OFF1	"Welcome BACK! You were away"
#define MSG_AFK_MODE_OFF2	"minutes!.\n"
#define MSG_AFK_MODE_OFF3	"new messages were stored in your ysm\ndirectory in the file"
#define MSG_AFK_MODE_OFF4	"while you were away.\nUse 'readafk' to read or clean the stored messages!.\nLeaving" BRIGHT_BLUE " AFK " NORMAL "mode..\n"

#define MSG_AFK_READ_MSG	GREEN "[[ Reading stored AFK Messages ]]" NORMAL

/* ERROR MESSAGES */

#define MSG_ERR_PASSMATCH	CYAN "<<NO!>>" NORMAL " Passwords do NOT match."
#define MSG_ERR_DISCONNECTED	"Disconnected by the Server. Check your password."
#define MSG_ERR_INVPASSWD	RED "Server said: Bad Password." NORMAL
#define MSG_ERR_INVUIN		RED "Server said: Invalid UIN." NORMAL
#define MSG_ERR_TOOMC		RED "Server said: Too many clients from the same IP." NORMAL
#define MSG_ERR_RATE		RED "Server said: Rate limit exceeded. Try again later." NORMAL
#define MSG_ERR_SAMEUIN		CYAN "!PARANOID!" NORMAL " Someone else logged in using this ICQ UIN." 

#define MSG_ERR_CONNECT		"Connect failed!"
#define MSG_ERR_PROXY		"Proxy returned an ERROR!::"
#define MSG_ERR_PROXY2		"Proxy requires Authorization.\n"
#define MSG_ERR_PROXY3		"Method Failed. Unknown Reason.\n"
#define MSG_ERR_REGISTERING	"Invalid Server Response While Registering. Leaving."

#define MSG_ERR_FEATUREDISABLED	"Feature disabled. Recompile YSM with Threads support."

#define MSG_CONN_PROXYOK	"Connected to the PROXY!"
#define MSG_CONN_SERVEROK	"TCP connection established with ICQ SERVER"

#define MSG_AOL_WARNING		"AOL Warning! stop sending messages too fast!"

#define MSG_REQ_SENT1		"YSM Request Sent to"
#define MSG_REQ_SENT2		"Slave called"

#define MSG_AUTH_SENT1		"YSM Authorization Sent to"
#define MSG_AUTH_SENT2		"Slave called"

#define MSG_NEW_OFFLINE		"Message received when you were" BRIGHT_BLUE " offline"

#define MSG_BUDDY_GROUPCREATED	"YSM Group Created."
#define MSG_BUDDY_SAVING1	BRIGHT_BLUE "Saving ["
#define MSG_BUDDY_SAVING2	"]" WHITE " ["
#define MSG_BUDDY_SAVING3	"]" NORMAL	

#define MSG_BUDDY_SAVINGOK	GREEN " [OK] SLAVE SAVED"
#define MSG_BUDDY_SAVINGERROR	RED " [ERROR]"
#define MSG_BUDDY_SAVINGERROR2	"Maybe adding a disabled account?."


#define MSG_BUDDY_SAVINGAUTH	RED " [AUTH]"
#define MSG_BUDDY_SAVINGAUTH2	"Authorization from the user is required."
#define MSG_BUDDY_SAVINGAUTH3	" [use the 'req' command]."

#define MSG_BUDDY_BLOCKWARN	"Receiving Slave status information."
#define MSG_BUDDY_BLOCKWARN2	"Your input may get blocked for a few seconds."

#define MSG_REG_SUCCESFULL	"Registration Succesfull. Your new UIN is "

#define MSG_INFO_UPDATED	"Information Updated!"

#define MSG_SEARCH_FAILED	"Search Failed. valid UIN/Mail?"

#define MSG_DIRECT_CONNECTING	"Hold on. Connecting to "
#define MSG_DIRECT_ESTABLISHED	"Connection Established."
#define MSG_DIRECT_ERR1	"Can't establish a Direct Connection from behind a proxy."
#define MSG_DIRECT_ERR2	"Can't establish a Direct Connection.\nEither the remote IP or listening Port are unknown."
#define MSG_DIRECT_ERR3 "Can't establish a Direct Connection.\nConnection Refused"

==> ysmv7_2_9_9_1.tar.gz: ysmv7_2_9_9_1/src/YSMLangs/english.h <==
/*	$Id: english.h,v 1.10 2005/08/16 00:28:08 rad2k Exp $	*/

/*
 * YSM Language Specific header file
 *
 *	ENGLISH LANGUAGE
 *
 * by rad2k
 *
 */


/* YSM STARTING MESSAGES */

#define MSG_STARTING_ONE	"..an" WHITE " Experience" NORMAL " you will never forget.."
#define MSG_STARTING_TWO	"[ INITIALIZING YSM ][ " BLUE "UIN" NORMAL " TO USE :"
#define MSG_FOUND_SECPASS	"Found a Secured Password. I love Paranoid users ;)."
#define MSG_FOUND_SECPASS2	"Type again [verification]: "
#define MSG_READ_SLAVES		"YSM Amount of Slaves in db" BRIGHT_BLUE " ["
#define MSG_ASK_KEYMAP1		"Default shortcuts are: "
#define MSG_ASK_KEYMAP2		"Would you like to re-configure your key map? [Y/N]:"
#define MSG_NETWORK_INFO	"[Network Information: TCP local port:"
#define MSG_NETWORK_INFO2	"Ok New srv. Information arrived."
#define MSG_NETWORK_INFO3	"Connecting to the BOS 2nd Server.."
#define MSG_LOGIN_OK		BLUE "Login OK!" NORMAL " << Welcome to the ICQ Network >>"
#define MSG_ASK_DOWNLOAD1	"AVAILABLE Contacts stored in the ICQ servers were found."
#define MSG_ASK_DOWNLOAD2	"Do you wish to download them? [Y/N]: "
#define MSG_DOWNLOADED_SLAVES	"downloaded SLAVES belong to your kingdom."

/* YSM SLAVES INTERACTION MESSAGES */

#define MSG_STATUS_CHANGE1	"[A Slave #"
#define MSG_STATUS_CHANGE2	", called" BLUE
#define MSG_STATUS_CHANGE3	NORMAL "changed his mood to:"

#define MSG_STATUS_HIDE1	"[A Slave #"
#define MSG_STATUS_HIDE2	", called" BLUE
#define MSG_STATUS_HIDE3	NORMAL "hides from you in:"

#define MSG_MESSAGE_SENT1	MAGENTA "YSM Msg Sent to Slave called" WHITE
#define MSG_MESSAGE_SENT2	MAGENTA "YSM Msg Sent to" WHITE

#define MSG_MESSAGE_SENT3	MAGENTA	"Encrypted Msg Sent to Slave called" WHITE
#define MSG_MESSAGE_SENT4	MAGENTA	"Encrypted Msg Sent to" WHITE

#define MSG_INCOMING_MESSAGE	"[Incoming Msg]"
#define MSG_INCOMING_URL	"[Incoming URL]"
#define MSG_INCOMING_AUTHR	"Incoming Authorization Request from"

#define MSG_INCOMING_PAGER	"[Pager Message]"

#define MSG_SLAVES_LIST		"You OWN the Following"
#define MSG_SLAVES_ONLINE	"These are the CURRENTLY ONLINE SLAVES you own:"

#define MSG_SLAVES_BIRTHDAY	WHITE "BIRTHDAY" NORMAL

#define MSG_WARN_ADDED		"Get Paranoid! an ICQ user added you to his/her list!"
#define MSG_WARN_AUTHOK		"Fine! You were authorized to make him/her your Slave by the ICQ"
#define MSG_WARN_AUTHDENY	"WTF! the redneck bastard -DENIED- your Auth request"

/* YSM AFK RELATED MESSAGES */

#define MSG_IDLE_TIME_REACHED	"IDLE Time reached. going afk..\n"
#define MSG_AFK_MODE_ON		"You are " BRIGHT_BLUE "now in AFK" NORMAL " mode (Away From Keyboard).\nIncoming Messages will be logged and an autoreply will be sent\nto anyone who messages you.\nyou can then type 'afk' again to leave AFK mode. enjoy your coffee ;)"

#define MSG_AFK_MODE_OFF1	"Welcome BACK! You were away"
#define MSG_AFK_MODE_OFF2	"minutes!.\n"
#define MSG_AFK_MODE_OFF3	"new messages were stored in your ysm\ndirectory in the file"
#define MSG_AFK_MODE_OFF4	"while you were away.\nUse 'readafk' to read or clean the stored messages!.\nLeaving" BRIGHT_BLUE " AFK " NORMAL "mode..\n"

#define MSG_AFK_READ_MSG	GREEN "[[ Reading stored AFK Messages ]]" NORMAL

/* ERROR MESSAGES */

#define MSG_ERR_PASSMATCH	CYAN "<<NO!>>" NORMAL " Passwords do NOT match."
#define MSG_ERR_DISCONNECTED	"Disconnected by the Server. Check your password."
#define MSG_ERR_INVPASSWD	RED "Server said: Bad Password." NORMAL
#define MSG_ERR_INVUIN		RED "Server said: Invalid UIN." NORMAL
#define MSG_ERR_TOOMC		RED "Server said: Too many clients from the same IP." NORMAL
#define MSG_ERR_RATE		RED "Server said: Rate limit exceeded. Try again later." NORMAL
#define MSG_ERR_SAMEUIN		CYAN "!PARANOID!" NORMAL " Someone else logged in using this ICQ UIN." 

#define MSG_ERR_CONNECT		"Connect failed!"
#define MSG_ERR_PROXY		"Proxy returned an ERROR!::"
#define MSG_ERR_PROXY2		"Proxy requires Authorization.\n"
#define MSG_ERR_PROXY3		"Method Failed. Unknown Reason.\n"
#define MSG_ERR_REGISTERING	"Invalid Server Response While Registering. Leaving."

#define MSG_ERR_FEATUREDISABLED	"Feature disabled. Recompile YSM with Threads support."

#define MSG_CONN_PROXYOK	"Connected to the PROXY!"
#define MSG_CONN_SERVEROK	"TCP connection established with ICQ SERVER"

#define MSG_AOL_WARNING		"AOL Warning! stop sending messages too fast!"

#define MSG_REQ_SENT1		"YSM Request Sent to"
#define MSG_REQ_SENT2		"Slave called"

#define MSG_AUTH_SENT1		"YSM Authorization Sent to"
#define MSG_AUTH_SENT2		"Slave called"

#define MSG_NEW_OFFLINE		"Message received when you were" BRIGHT_BLUE " offline"

#define MSG_BUDDY_GROUPCREATED	"YSM Group Created."
#define MSG_BUDDY_SAVING1	BRIGHT_BLUE "Saving ["
#define MSG_BUDDY_SAVING2	"]" WHITE " ["
#define MSG_BUDDY_SAVING3	"]" NORMAL	

#define MSG_BUDDY_SAVINGOK	GREEN " [OK] SLAVE SAVED"
#define MSG_BUDDY_SAVINGERROR	RED " [ERROR]"
#define MSG_BUDDY_SAVINGERROR2	"Maybe adding a disabled account?."


#define MSG_BUDDY_SAVINGAUTH	RED " [AUTH]"
#define MSG_BUDDY_SAVINGAUTH2	"Authorization from the user is required."
#define MSG_BUDDY_SAVINGAUTH3	" [use the 'req' command]."

#define MSG_BUDDY_BLOCKWARN	"Receiving Slave status information."
#define MSG_BUDDY_BLOCKWARN2	"Your input may get blocked for a few seconds."

#define MSG_REG_SUCCESFULL	"Registration Succesfull. Your new UIN is "
#define MSG_REG_FAILED		RED "UIN Registration failed. This may be due to too many registration requests from the same IP address. Please try again later." NORMAL

#define MSG_INFO_UPDATED	"Information Updated!"

#define MSG_SEARCH_FAILED	"Search Failed. valid UIN/Mail?"

#define MSG_DIRECT_CONNECTING	"Hold on. Connecting to "
#define MSG_DIRECT_ESTABLISHED	"Connection Established."
#define MSG_DIRECT_ERR1	"Can't establish a Direct Connection from behind a proxy."
#define MSG_DIRECT_ERR2	"Can't establish a Direct Connection.\nEither the remote IP or listening Port are unknown."
#define MSG_DIRECT_ERR3 "Can't establish a Direct Connection.\nConnection Refused"
